@@ -14,7 +14,6 @@ import threading
 import subprocess
 import sys
 
-
 ####
 # Helper to allow Enum type to be used which allows better code readability
 #
@@ -109,23 +108,25 @@ def GetNugetCmd():
 # @param capture - boolean to determine if caller wants the output captured in any format.
 # @param workingdir - path to set to the working directory before running the command.
 # @param outfile - capture output to file of given path.
-# @param outstream - capture output to a stream.  
+# @param outstream - capture output to a stream.
+# @param environ - shell environment variables dictionary that replaces the one inherited from the
+#                  current process.
 #
 # @return returncode of called cmd
 ####
-def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstream=None):
+def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstream=None, environ=None):
     cmd = cmd.strip('"\'')
     if " " in cmd:
         cmd = '"' + cmd + '"'
-    parameters = parameters.strip()
     if parameters is not None:
+        parameters = parameters.strip()
         cmd += " " + parameters
     starttime = datetime.datetime.now()
     logging.info("Cmd to run is: " + cmd)
     logging.info("------------------------------------------------")
     logging.info("--------------Cmd Output Starting---------------")
     logging.info("------------------------------------------------")
-    c = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, cwd=workingdir, shell=True)
+    c = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, cwd=workingdir, shell=True, env=environ)
     if(capture):
         outr = PropagatingThread(target=reader, args=(outfile, outstream, c.stdout,))
         outr.start()
@@ -151,11 +152,13 @@ def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstre
 # @param capture - boolean to determine if caller wants the output captured in any format.
 # @param workingdir - path to set to the working directory before running the command.
 # @param outfile - capture output to file of given path.
-# @param outstream - capture output to a stream.  
+# @param outstream - capture output to a stream.
+# @param environ - shell environment variables dictionary that replaces the one inherited from the
+#                  current process.
 #
 # @return returncode of called cmd
 ####
-def RunPythonScript(pythonfile, params, capture=True, workingdir=None, outfile=None, outstream=None):
+def RunPythonScript(pythonfile, params, capture=True, workingdir=None, outfile=None, outstream=None, environ=None):
     #locate python file on path
     pythonfile.strip('"\'')
     if " " in pythonfile:
@@ -175,9 +178,8 @@ def RunPythonScript(pythonfile, params, capture=True, workingdir=None, outfile=N
                 pythonfile = os.path.join(a, pythonfile)
                 logging.debug("Python Script was found on the path: %s" % pythonfile)
                 break
-    params = pythonfile + " " + ' '.join(params.split())
-    return RunCmd(sys.executable, params, capture=capture, workingdir=workingdir, outfile=outfile, outstream=outstream)
-
+    params = pythonfile + " " + params
+    return RunCmd(sys.executable, params, capture=capture, workingdir=workingdir, outfile=outfile, outstream=outstream, environ=environ)
 ####
 # Locally Sign input file using Windows SDK signtool.  This will use a local Pfx file.  
 # WARNING!!! : This should not be used for production signing as that process should follow stronger security practices (HSM / smart cards / etc)
